@@ -246,10 +246,10 @@ class GetRolePermissionAction(Action):
         perms = models.RolePermission.objects.filter(role=int(context.userrole_id))
         res = []
         for perm in perms:
-            codes = perm.permission_code.split('#')
+            codes = str(perm.permission_code).split('#')
             act_code = codes[0]
             sub_code = codes[1] if len(codes) > 1 else ''
-            act = ControllerCache.get_action_by_url(act_code)
+            act = ControllerCache.find_node_by_perm(act_code)
             if not act:
                 perm.verbose_name = PERM_OBJECT_NOT_FOUND
                 # попробуем найти набор экшенов, если есть суб-код
@@ -264,7 +264,7 @@ class GetRolePermissionAction(Action):
                 if act.parent:
                     pack_name = act.parent.get_verbose_name()
                 else:
-                    pack_name = ''
+                    pack_name = act.get_verbose_name()
                 perm.verbose_name = '%s - %s' % (pack_name, act.verbose_name if act.verbose_name else act.__class__.__name__)
                 if sub_code and sub_code in act.sub_permissions:
                     perm.verbose_name = '%s - %s' % (pack_name, act.sub_permissions[sub_code])
